from dataclasses import dataclass
from typing import List, Optional

from pygrype.core.scan.cvss import CVSS
from pygrype.core.scan.vulnerability_fix import VulnerabilityFix


@dataclass
class Vulnerability:
    id: str
    description: Optional[str]
    dataSource: str
    namespace: str
    severity: Optional[str]
    urls: List[str]
    cvss: List[CVSS]
    fix: Optional[VulnerabilityFix]
